export interface SyncedProject {
    /** Project ID in Portfolio - if project was yet to be create, will be None */
    portfolioProjectId?: string | null;
    /** External Project ID */
    externalId?: string;
    /** Project name */
    title?: string | null;
    /** Project media count */
    mediaCount?: number;
    /** Project image url */
    coverImage?: string | null;
    /** Project url in external */
    link?: string | null;
    /**
     * Represents the last time project was synced - returned only if external project is synced
     * @readonly
     */
    lastSynced?: Date | null;
    /** External Project synced status */
    status?: SyncStatus;
}
export declare enum SyncStatus {
    /** Project was not synced */
    NOT_SYNCED = "NOT_SYNCED",
    /** Project is in pending state */
    PENDING = "PENDING",
    /** Project is in syncing state */
    SYNCING = "SYNCING",
    /** Project was synced */
    SYNCED = "SYNCED"
}
export interface SyncingProjectEvent {
    /** Provider appDefId */
    appDefId?: string;
    /** External Project ID */
    externalProjectId?: string;
    /** Portfolio Project ID */
    portfolioProjectId?: string;
    /** When the first event was produced, and started syncing */
    firstProduceTimestamp?: Date | null;
    /** Project Revision */
    projectSyncRevision?: Date | null;
}
export interface SyncProjectPagingEvent {
    /** Provider appDefId */
    appDefId?: string;
    /** External Project ID */
    externalProjectId?: string;
    /** Portfolio Project ID */
    portfolioProjectId?: string;
    /** Next page cursor */
    nextPageCursor?: string | null;
    /** Project Revision */
    projectSyncRevision?: Date | null;
}
export interface SyncSiteEvent {
    /** Portfolio instance id */
    instanceId?: string;
    /** Paging */
    paging?: CursorPaging;
}
export interface CursorPaging {
    /** Maximum number of items to return in the results. */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
export interface SyncProjectRequest {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
export interface GetProjectsRequest {
    /** Provider appDefId */
    appDefId: string;
    /** Paging */
    paging?: CursorPaging;
}
export interface GetProjectsResponse {
    /** Provider appDefId */
    projects?: SyncedProject[];
    /** Paging metadata */
    metadata?: PagingMetadataV2;
}
export interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
export interface Cursors {
    /** Cursor string pointing to the next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to the previous page in the list of results. */
    prev?: string | null;
}
export interface SyncProjectResponse {
    /** Portfolio project */
    project?: SyncedProject;
}
export interface GetSyncStatusRequest {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
export interface GetSyncStatusResponse {
    /** Provider appDefId */
    appDefId?: string;
    /** External Project ID */
    externalId?: string;
    /** Synced status */
    status?: SyncStatus;
}
export interface StopSyncRequest {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
export interface StopSyncResponse {
    /** Provider appDefId */
    appDefId?: string;
    /** External Project ID */
    externalId?: string;
}
export interface GetLoginRedirectableUrlRequest {
    /** Provider appDefId */
    appDefId: string;
}
export interface GetLoginRedirectableUrlResponse {
    /** Provider appDefId */
    appDefId?: string;
    /** Login url */
    url?: string;
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface Empty {
}
export interface ItemCreatedMediaCallbackRequest {
    appDefId?: string;
    /** External Project ID */
    projectExternalId?: string;
    /** External Project ID */
    itemExternalId?: string;
    fileName?: string | null;
    mediaType?: string | null;
    opStatus?: string | null;
    fileSize?: number | null;
    width?: number | null;
    height?: number | null;
    fileOutput?: MediaFileOutput;
    siteId?: string | null;
}
export interface MediaFileOutput {
    video?: MediaVideoOutput[];
    image?: MediaImageOutput[];
}
export interface MediaVideoOutput {
    key?: string | null;
    status?: string | null;
    url?: string | null;
    quality?: string | null;
    duration?: number | null;
    width?: number | null;
    height?: number | null;
    format?: string | null;
}
export interface MediaImageOutput {
    key?: string | null;
    status?: string | null;
    url?: string | null;
    width?: number | null;
    height?: number | null;
    format?: string | null;
}
export interface ItemCreatedMediaCallbackResponse {
}
export interface ProjectCoverImageCreatedMediaCallbackRequest {
    appDefId?: string;
    /** External Project ID */
    projectExternalId?: string;
    fileName?: string | null;
    mediaType?: string | null;
    opStatus?: string | null;
    fileSize?: number | null;
    width?: number | null;
    height?: number | null;
    fileOutput?: MediaFileOutput;
    siteId?: string | null;
}
export interface ProjectCoverImageCreatedMediaCallbackResponse {
}
export interface MetaSiteSpecialEvent extends MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
    /** A meta site id. */
    metaSiteId?: string;
    /** A meta site version. Monotonically increasing. */
    version?: string;
    /** A timestamp of the event. */
    timestamp?: string;
    /**
     * TODO(meta-site): Change validation once validations are disabled for consumers
     * More context: https://wix.slack.com/archives/C0UHEBPFT/p1720957844413149 and https://wix.slack.com/archives/CFWKX325T/p1728892152855659
     */
    assets?: Asset[];
}
/** @oneof */
export interface MetaSiteSpecialEventPayloadOneOf {
    /** Emitted on a meta site creation. */
    siteCreated?: SiteCreated;
    /** Emitted on a meta site transfer completion. */
    siteTransferred?: SiteTransferred;
    /** Emitted on a meta site deletion. */
    siteDeleted?: SiteDeleted;
    /** Emitted on a meta site restoration. */
    siteUndeleted?: SiteUndeleted;
    /** Emitted on the first* publish of the meta site (* switching from unpublished to published state). */
    sitePublished?: SitePublished;
    /** Emitted on a meta site unpublish. */
    siteUnpublished?: SiteUnpublished;
    /** Emitted when meta site is marked as template. */
    siteMarkedAsTemplate?: SiteMarkedAsTemplate;
    /** Emitted when meta site is marked as a WixSite. */
    siteMarkedAsWixSite?: SiteMarkedAsWixSite;
    /** Emitted when an application is provisioned (installed). */
    serviceProvisioned?: ServiceProvisioned;
    /** Emitted when an application is removed (uninstalled). */
    serviceRemoved?: ServiceRemoved;
    /** Emitted when meta site name (URL slug) is changed. */
    siteRenamedPayload?: SiteRenamed;
    /** Emitted when meta site was permanently deleted. */
    hardDeleted?: SiteHardDeleted;
    /** Emitted on a namespace change. */
    namespaceChanged?: NamespaceChanged;
    /** Emitted when Studio is attached. */
    studioAssigned?: StudioAssigned;
    /** Emitted when Studio is detached. */
    studioUnassigned?: StudioUnassigned;
}
export interface Asset {
    /** An application definition id (app_id in dev-center). For legacy reasons may be UUID or a string (from Java Enum). */
    appDefId?: string;
    /** An instance id. For legacy reasons may be UUID or a string. */
    instanceId?: string;
    /** An application state. */
    state?: State;
}
export declare enum State {
    UNKNOWN = "UNKNOWN",
    ENABLED = "ENABLED",
    DISABLED = "DISABLED",
    PENDING = "PENDING",
    DEMO = "DEMO"
}
export interface SiteCreated {
    /** A template identifier (empty if not created from a template). */
    originTemplateId?: string;
    /** An account id of the owner. */
    ownerId?: string;
    /** A context in which meta site was created. */
    context?: SiteCreatedContext;
    /**
     * A meta site id from which this site was created.
     *
     * In case of a creation from a template it's a template id.
     * In case of a site duplication ("Save As" in dashboard or duplicate in UM) it's an id of a source site.
     */
    originMetaSiteId?: string | null;
    /** A meta site name (URL slug). */
    siteName?: string;
    /** A namespace. */
    namespace?: Namespace;
}
export declare enum SiteCreatedContext {
    /** A valid option, we don't expose all reasons why site might be created. */
    OTHER = "OTHER",
    /** A meta site was created from template. */
    FROM_TEMPLATE = "FROM_TEMPLATE",
    /** A meta site was created by copying of the transfferred meta site. */
    DUPLICATE_BY_SITE_TRANSFER = "DUPLICATE_BY_SITE_TRANSFER",
    /** A copy of existing meta site. */
    DUPLICATE = "DUPLICATE",
    /** A meta site was created as a transfferred site (copy of the original), old flow, should die soon. */
    OLD_SITE_TRANSFER = "OLD_SITE_TRANSFER",
    /** deprecated A meta site was created for Flash editor. */
    FLASH = "FLASH"
}
export declare enum Namespace {
    UNKNOWN_NAMESPACE = "UNKNOWN_NAMESPACE",
    /** Default namespace for UGC sites. MetaSites with this namespace will be shown in a user's site list by default. */
    WIX = "WIX",
    /** ShoutOut stand alone product. These are siteless (no actual Wix site, no HtmlWeb). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    SHOUT_OUT = "SHOUT_OUT",
    /** MetaSites created by the Albums product, they appear as part of the Albums app. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ALBUMS = "ALBUMS",
    /** Part of the WixStores migration flow, a user tries to migrate and gets this site to view and if the user likes it then stores removes this namespace and deletes the old site with the old stores. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    WIX_STORES_TEST_DRIVE = "WIX_STORES_TEST_DRIVE",
    /** Hotels standalone (siteless). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    HOTELS = "HOTELS",
    /** Clubs siteless MetaSites, a club without a wix website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    CLUBS = "CLUBS",
    /** A partially created ADI website. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    ONBOARDING_DRAFT = "ONBOARDING_DRAFT",
    /** AppBuilder for AppStudio / shmite (c). MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_SITE = "DEV_SITE",
    /** LogoMaker websites offered to the user after logo purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    LOGOS = "LOGOS",
    /** VideoMaker websites offered to the user after video purchase. MetaSites with this namespace will *not* be shown in a user's site list by default. */
    VIDEO_MAKER = "VIDEO_MAKER",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    PARTNER_DASHBOARD = "PARTNER_DASHBOARD",
    /** MetaSites with this namespace will *not* be shown in a user's site list by default. */
    DEV_CENTER_COMPANY = "DEV_CENTER_COMPANY",
    /**
     * A draft created by HTML editor on open. Upon "first save" it will be moved to be of WIX domain.
     *
     * Meta site with this namespace will *not* be shown in a user's site list by default.
     */
    HTML_DRAFT = "HTML_DRAFT",
    /**
     * the user-journey for Fitness users who want to start from managing their business instead of designing their website.
     * Will be accessible from Site List and will not have a website app.
     * Once the user attaches a site, the site will become a regular wixsite.
     */
    SITELESS_BUSINESS = "SITELESS_BUSINESS",
    /** Belongs to "strategic products" company. Supports new product in the creator's economy space. */
    CREATOR_ECONOMY = "CREATOR_ECONOMY",
    /** It is to be used in the Business First efforts. */
    DASHBOARD_FIRST = "DASHBOARD_FIRST",
    /** Bookings business flow with no site. */
    ANYWHERE = "ANYWHERE",
    /** Namespace for Headless Backoffice with no editor */
    HEADLESS = "HEADLESS",
    /**
     * Namespace for master site that will exist in parent account that will be referenced by subaccounts
     * The site will be used for account level CSM feature for enterprise
     */
    ACCOUNT_MASTER_CMS = "ACCOUNT_MASTER_CMS",
    /** Rise.ai Siteless account management for Gift Cards and Store Credit. */
    RISE = "RISE",
    /**
     * As part of the branded app new funnel, users now can create a meta site that will be branded app first.
     * There's a blank site behind the scene but it's blank).
     * The Mobile company will be the owner of this namespace.
     */
    BRANDED_FIRST = "BRANDED_FIRST",
    /** Nownia.com Siteless account management for Ai Scheduling Assistant. */
    NOWNIA = "NOWNIA",
    /**
     * UGC Templates are templates that are created by users for personal use and to sale to other users.
     * The Partners company owns this namespace.
     */
    UGC_TEMPLATE = "UGC_TEMPLATE",
    /** Codux Headless Sites */
    CODUX = "CODUX",
    /** Bobb - AI Design Creator. */
    MEDIA_DESIGN_CREATOR = "MEDIA_DESIGN_CREATOR",
    /**
     * Shared Blog Site is a unique single site across Enterprise account,
     * This site will hold all Blog posts related to the Marketing product.
     */
    SHARED_BLOG_ENTERPRISE = "SHARED_BLOG_ENTERPRISE"
}
/** Site transferred to another user. */
export interface SiteTransferred {
    /** A previous owner id (user that transfers meta site). */
    oldOwnerId?: string;
    /** A new owner id (user that accepts meta site). */
    newOwnerId?: string;
}
/** Soft deletion of the meta site. Could be restored. */
export interface SiteDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
export interface DeleteContext {
    /** When the meta site was deleted. */
    dateDeleted?: Date | null;
    /** A status. */
    deleteStatus?: DeleteStatus;
    /** A reason (flow). */
    deleteOrigin?: string;
    /** A service that deleted it. */
    initiatorId?: string | null;
}
export declare enum DeleteStatus {
    UNKNOWN = "UNKNOWN",
    TRASH = "TRASH",
    DELETED = "DELETED",
    PENDING_PURGE = "PENDING_PURGE"
}
/** Restoration of the meta site. */
export interface SiteUndeleted {
}
/** First publish of a meta site. Or subsequent publish after unpublish. */
export interface SitePublished {
}
export interface SiteUnpublished {
    /** A list of URLs previously associated with the meta site. */
    urls?: string[];
}
export interface SiteMarkedAsTemplate {
}
export interface SiteMarkedAsWixSite {
}
/**
 * Represents a service provisioned a site.
 *
 * Note on `origin_instance_id`:
 * There is no guarantee that you will be able to find a meta site using `origin_instance_id`.
 * This is because of the following scenario:
 *
 * Imagine you have a template where a third-party application (TPA) includes some stub data,
 * such as a product catalog. When you create a site from this template, you inherit this
 * default product catalog. However, if the template's product catalog is modified,
 * your site will retain the catalog as it was at the time of site creation. This ensures that
 * your site remains consistent with what you initially received and does not include any
 * changes made to the original template afterward.
 * To ensure this, the TPA on the template gets a new instance_id.
 */
export interface ServiceProvisioned {
    /** Either UUID or EmbeddedServiceType. */
    appDefId?: string;
    /** Not only UUID. Something here could be something weird. */
    instanceId?: string;
    /** An instance id from which this instance is originated. */
    originInstanceId?: string;
    /** A version. */
    version?: string | null;
    /** The origin meta site id */
    originMetaSiteId?: string | null;
}
export interface ServiceRemoved {
    /** Either UUID or EmbeddedServiceType. */
    appDefId?: string;
    /** Not only UUID. Something here could be something weird. */
    instanceId?: string;
    /** A version. */
    version?: string | null;
}
/** Rename of the site. Meaning, free public url has been changed as well. */
export interface SiteRenamed {
    /** A new meta site name (URL slug). */
    newSiteName?: string;
    /** A previous meta site name (URL slug). */
    oldSiteName?: string;
}
/**
 * Hard deletion of the meta site.
 *
 * Could not be restored. Therefore it's desirable to cleanup data.
 */
export interface SiteHardDeleted {
    /** A deletion context. */
    deleteContext?: DeleteContext;
}
export interface NamespaceChanged {
    /** A previous namespace. */
    oldNamespace?: Namespace;
    /** A new namespace. */
    newNamespace?: Namespace;
}
/** Assigned Studio editor */
export interface StudioAssigned {
}
/** Unassigned Studio editor */
export interface StudioUnassigned {
}
export interface SyncAllSitesEvent {
    /** Paging */
    paging?: CursorPaging;
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface SyncedProjectNonNullableFields {
    externalId: string;
    mediaCount: number;
    status: SyncStatus;
}
export interface GetProjectsResponseNonNullableFields {
    projects: SyncedProjectNonNullableFields[];
}
export interface SyncProjectResponseNonNullableFields {
    project?: SyncedProjectNonNullableFields;
}
export interface GetSyncStatusResponseNonNullableFields {
    appDefId: string;
    externalId: string;
    status: SyncStatus;
}
export interface StopSyncResponseNonNullableFields {
    appDefId: string;
    externalId: string;
}
export interface GetLoginRedirectableUrlResponseNonNullableFields {
    appDefId: string;
    url: string;
}
/**
 * Get projects per app
 * @param appDefId - Provider appDefId
 * @public
 * @documentationMaturity preview
 * @requiredField appDefId
 * @permissionId PORTFOLIO.SYNCED_PROJECTS_READ
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @applicableIdentity APP
 * @fqn com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetProjects
 */
export declare function getProjects(appDefId: string, options?: GetProjectsOptions): Promise<GetProjectsResponse & GetProjectsResponseNonNullableFields>;
export interface GetProjectsOptions {
    /** Paging */
    paging?: CursorPaging;
}
/**
 * Async Sync project
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appDefId
 * @requiredField identifiers.externalId
 * @permissionId PORTFOLIO.SYNCED_PROJECTS_SYNC
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @applicableIdentity APP
 * @fqn com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.SyncProject
 */
export declare function syncProject(identifiers: SyncProjectIdentifiers): Promise<SyncProjectResponse & SyncProjectResponseNonNullableFields>;
export interface SyncProjectIdentifiers {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
/**
 * Get sync status (when was last synced and etc..)
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appDefId
 * @requiredField identifiers.externalId
 * @permissionId PORTFOLIO.SYNCED_PROJECTS_READ
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @applicableIdentity APP
 * @fqn com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetSyncStatus
 */
export declare function getSyncStatus(identifiers: GetSyncStatusIdentifiers): Promise<GetSyncStatusResponse & GetSyncStatusResponseNonNullableFields>;
export interface GetSyncStatusIdentifiers {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
/**
 * Stop sync project
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appDefId
 * @requiredField identifiers.externalId
 * @permissionId PORTFOLIO.SYNCED_PROJECTS_STOP_SYNC
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @applicableIdentity APP
 * @fqn com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.StopSync
 */
export declare function stopSync(identifiers: StopSyncIdentifiers): Promise<StopSyncResponse & StopSyncResponseNonNullableFields>;
export interface StopSyncIdentifiers {
    /** Provider appDefId */
    appDefId: string;
    /** External Project ID */
    externalId: string;
}
/**
 * Get login redirectable url
 * @param appDefId - Provider appDefId
 * @public
 * @documentationMaturity preview
 * @requiredField appDefId
 * @permissionId PORTFOLIO.SYNCED_PROJECTS_READ
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @applicableIdentity APP
 * @fqn com.wixpress.portfolio.syncedprojects.spi_host.v1.SyncedProjectsService.GetLoginRedirectableUrl
 */
export declare function getLoginRedirectableUrl(appDefId: string): Promise<GetLoginRedirectableUrlResponse & GetLoginRedirectableUrlResponseNonNullableFields>;
export {};
